@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct EnterpriseAdmin {
-    client: Client,
+    pub client: Client,
 }
 
 impl EnterpriseAdmin {
@@ -65,10 +65,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -95,24 +92,18 @@ impl EnterpriseAdmin {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::EnterpriseAdminListOrgAccessSelfHostedRunnerGroupInResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/actions/permissions/organizations?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -144,10 +135,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -264,10 +252,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -294,24 +279,18 @@ impl EnterpriseAdmin {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::EnterpriseAdminListSelfHostedRunnerGroupsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/actions/runner-groups?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -343,10 +322,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -439,10 +415,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -471,25 +444,19 @@ impl EnterpriseAdmin {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::EnterpriseAdminListOrgAccessSelfHostedRunnerGroupInResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/actions/runner-groups/{}/organizations?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
             crate::progenitor_support::encode_path(&runner_group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -524,10 +491,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -622,25 +586,19 @@ impl EnterpriseAdmin {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::ActionsListSelfHostedRunnersInGroupOrgResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/actions/runner-groups/{}/runners?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
             crate::progenitor_support::encode_path(&runner_group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -675,10 +633,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -772,24 +727,18 @@ impl EnterpriseAdmin {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::EnterpriseAdminListSelfHostedRunnersResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/actions/runners?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1017,35 +966,33 @@ impl EnterpriseAdmin {
         page: i64,
         per_page: i64,
     ) -> Result<Vec<crate::types::AuditLogEvent>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !after.is_empty() {
-            query_args.push(format!("after={}", after));
+            query_args.push(("after".to_string(), after.to_string()));
         }
         if !before.is_empty() {
-            query_args.push(format!("before={}", before));
+            query_args.push(("before".to_string(), before.to_string()));
+        }
+        if !include.to_string().is_empty() {
+            query_args.push(("include".to_string(), include.to_string()));
+        }
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
         }
-        query_args.push(format!("include={}", include));
-        query_args.push(format!("order={}", order));
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !phrase.is_empty() {
-            query_args.push(format!("phrase={}", phrase));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("phrase".to_string(), phrase.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/audit-log?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1071,29 +1018,27 @@ impl EnterpriseAdmin {
         before: &str,
         order: crate::types::Order,
     ) -> Result<Vec<crate::types::AuditLogEvent>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !after.is_empty() {
-            query_args.push(format!("after={}", after));
+            query_args.push(("after".to_string(), after.to_string()));
         }
         if !before.is_empty() {
-            query_args.push(format!("before={}", before));
+            query_args.push(("before".to_string(), before.to_string()));
+        }
+        if !include.to_string().is_empty() {
+            query_args.push(("include".to_string(), include.to_string()));
+        }
+        if !order.to_string().is_empty() {
+            query_args.push(("order".to_string(), order.to_string()));
         }
-        query_args.push(format!("include={}", include));
-        query_args.push(format!("order={}", order));
         if !phrase.is_empty() {
-            query_args.push(format!("phrase={}", phrase));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("phrase".to_string(), phrase.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/enterprises/{}/audit-log?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1124,30 +1069,27 @@ impl EnterpriseAdmin {
         filter: &str,
         excluded_attributes: &str,
     ) -> Result<crate::types::ScimGroupListEnterprise> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if count > 0 {
-            query_args.push(format!("count={}", count));
+            query_args.push(("count".to_string(), count.to_string()));
         }
         if !excluded_attributes.is_empty() {
-            query_args.push(format!("excluded_attributes={}", excluded_attributes));
+            query_args.push((
+                "excludedAttributes".to_string(),
+                excluded_attributes.to_string(),
+            ));
         }
         if !filter.is_empty() {
-            query_args.push(format!("filter={}", filter));
+            query_args.push(("filter".to_string(), filter.to_string()));
         }
         if start_index > 0 {
-            query_args.push(format!("start_index={}", start_index));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("startIndex".to_string(), start_index.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/scim/v2/enterprises/{}/Groups?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1179,10 +1121,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1207,22 +1146,19 @@ impl EnterpriseAdmin {
         scim_group_id: &str,
         excluded_attributes: &str,
     ) -> Result<crate::types::ScimEnterpriseGroup> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !excluded_attributes.is_empty() {
-            query_args.push(format!("excluded_attributes={}", excluded_attributes));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push((
+                "excludedAttributes".to_string(),
+                excluded_attributes.to_string(),
+            ));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/scim/v2/enterprises/{}/Groups/{}?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
             crate::progenitor_support::encode_path(&scim_group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1257,10 +1193,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1321,10 +1254,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1368,27 +1298,21 @@ impl EnterpriseAdmin {
         count: i64,
         filter: &str,
     ) -> Result<crate::types::ScimUserListEnterprise> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if count > 0 {
-            query_args.push(format!("count={}", count));
+            query_args.push(("count".to_string(), count.to_string()));
         }
         if !filter.is_empty() {
-            query_args.push(format!("filter={}", filter));
+            query_args.push(("filter".to_string(), filter.to_string()));
         }
         if start_index > 0 {
-            query_args.push(format!("start_index={}", start_index));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("startIndex".to_string(), start_index.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/scim/v2/enterprises/{}/Users?{}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1422,10 +1346,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1490,10 +1411,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1569,10 +1487,7 @@ impl EnterpriseAdmin {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
